_G.LVMBase = _G.LVMBase or {}

LVMBase.ModPath = ModPath
LVMBase.SavePath = SavePath .. "LVMBaseOptions.txt"
LVMBase.Options = LVMBase.Options or {}
LVMBase.Menu = "LVMBaseMainMenu"

dofile( LVMBase.ModPath .. "lua/options.lua" )

local HookFiles = {

	["lib/managers/enemymanager"]			= "lua/lvm.lua",
	["lib/managers/gameplaycentralmanager"]	= "lua/lvm.lua",
	["lib/units/enemies/cop/copdamage"]		= "lua/lvm.lua"
	
}

function LVMBase:Save()

	local data = io.open( self.SavePath , "w+" )
	
	if data then
		data:write( json.encode( self.Options ) )
		data:close()
	end
	
end

function LVMBase:Load()

	local data = io.open( self.SavePath , "r" )
	
	if data then
		self.Options = json.decode( data:read( "*all" ) )
		data:close()
	end
	
end

function LVMBase:DefaultSettings()

	for k , v in pairs( LVMBase.MenuOptions.Toggle ) do
		if self:HasSetting( k ) == nil then LVMBase.Options[ k ] = v[ 4 ] end
	end

	-- for k , v in pairs( LVMBase.MenuOptions.Slider ) do
	-- 	if self:HasSetting( k ) == nil then LVMBase.Options[ k ] = v[ 4 ] end
	-- end

	self:Save()

end

function LVMBase:HasSetting( s )

	return LVMBase.Options[ s ]
	
end

LVMBase:Load()
LVMBase:DefaultSettings()

Hooks:Add( "MenuManagerSetupCustomMenus" , "LVMBaseMenuManagerPostSetupCustomMenus" , function( self , nodes )
    
	MenuHelper:NewMenu( LVMBase.Menu )
	
	for k , v in pairs( LVMBase.MenuOptions.Menu ) do
		MenuHelper:NewMenu( k )
	end
	
end )

Hooks:Add( "LocalizationManagerPostInit" , "LVMBaseLocalizationManagerPostInit" , function( self )

	self:load_localization_file( LVMBase.ModPath .. "loc/english.txt" )
	
	for _ , file in pairs( file.GetFiles( LVMBase.ModPath .. "loc/" ) ) do
		local loc = file:match( '^(.*).txt$' )
		
		if loc and Idstring( loc ) and Idstring( loc ):key() == SystemInfo:language():key() then
			self:load_localization_file( LVMBase.ModPath .. "loc/" .. file )
		end
	end

end )

Hooks:Add( "MenuManagerBuildCustomMenus" , "LVMBaseMenuManagerPostBuildCustomMenus" , function( self , nodes )
	
	nodes[ LVMBase.Menu ] = MenuHelper:BuildMenu( LVMBase.Menu , { focus_changed_callback = "LVMBaseMenuMOTDFocus" } )
    MenuHelper:AddMenuItem( nodes["blt_options"] , LVMBase.Menu , "LVMBase" , "LVMBase_desc" )
	
	for k , v in pairs( LVMBase.MenuOptions.Menu ) do	
		nodes[ k ] = MenuHelper:BuildMenu( k , v[ 4 ] )
		MenuHelper:AddMenuItem( nodes[ LVMBase.Menu ] , k , v[ 1 ] , v[ 2 ] , v[ 3 ] )
	end
	
end )

Hooks:Add( "MenuManagerPopulateCustomMenus" , "LVMBaseMenuManagerPostPopulateCustomMenus" , function( self , nodes )

	MenuCallbackHandler.LVMBaseMainMenuButtonCallback = function( self ) end
	
	MenuHelper:AddButton({
		id 			= "LVMBaseMainMenuButton",
		title 		= "",
		desc 		= "",
		callback 	= "LVMBaseMainMenuButtonCallback",
		menu_id 	= "LVMBaseMainMenu",
		localized 	= false
	})
	
	for k , v in pairs( LVMBase.MenuOptions.Toggle ) do
	
		MenuCallbackHandler[ k .. "Toggle" ] = function( self , item )
			LVMBase.Options[ k ] = item:value() == "on" or false
			LVMBase:Save()
		end
		
		MenuHelper:AddToggle({
			id 			= "ID" .. k .. "Toggle",
			title 		= v[ 2 ],
			desc 		= v[ 3 ],
			callback 	= k .. "Toggle",
			menu_id 	= v[ 1 ],
			value 		= LVMBase.Options[ k ]
		})
		
	end
	
	-- for k , v in pairs( LVMBase.MenuOptions.Slider ) do
	-- 	MenuCallbackHandler[ k .. "Slider" ] = function( self , item )
	-- 		LVMBase.Options[ k ] = item:value()
	-- 		LVMBase:Save()
	-- 	end
		
	-- 	MenuHelper:AddSlider({
	-- 		id 			= "ID" .. k .. "Slider",
	-- 		title 		= v[ 2 ],
	-- 		desc 		= v[ 3 ],
	-- 		callback 	= k .. "Slider",
	-- 		menu_id 	= v[ 1 ],
	-- 		value 		= LVMBase.Options[ k ],
	-- 		min 		= v[ 5 ],
	-- 		max			= v[ 6 ],
	-- 		step		= v[ 7 ],
	-- 		show_value	= true -- because why wouldnt you
	-- 	})
	-- end

end )

if RequiredScript then

	local requiredScript = RequiredScript:lower()
	
	if HookFiles[ requiredScript ] then
		dofile( LVMBase.ModPath .. HookFiles[ requiredScript ] )
	end
	
end